@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2002, 2013, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2014, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -18,8 +18,9 @@
   You should have received a copy of the GNU General Public License along with this
   program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
   Floor, Boston, MA 02110-1301  USA
- 
+
  */
+
 package com.mysql.jdbc;
 
 import java.io.InputStream;
@@ -308,8 +309,8 @@ public class CallableStatement extends PreparedStatement implements
 				mysqlTypeIfKnown = MysqlDefs.FIELD_TYPE_INT24;
 			}
 			
-			return ResultSetMetaData.getClassNameForJavaType(getParameterType(arg0), 
-					isUnsigned, mysqlTypeIfKnown, isBinaryOrBlob, false);
+			return ResultSetMetaData.getClassNameForJavaType(getParameterType(arg0), isUnsigned, mysqlTypeIfKnown,
+					isBinaryOrBlob, false, connection.getYearIsDateType());
 		}
 
 		public int getParameterCount() throws SQLException {
