@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2002, 2013, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2014, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -18,7 +18,7 @@
   You should have received a copy of the GNU General Public License along with this
   program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
   Floor, Boston, MA 02110-1301  USA
- 
+
  */
 
 package com.mysql.jdbc;
@@ -1733,6 +1733,18 @@ public interface ConnectionProperties {
 	
 	public abstract boolean getGetProceduresReturnsFunctions();
 
+	public abstract void setDetectCustomCollations(boolean detectCustomCollations);
+	
+	public abstract boolean getDetectCustomCollations();
+
 	String getConnectionAttributes() throws SQLException;
 
+	public abstract String getServerRSAPublicKeyFile();
+
+	public abstract void setServerRSAPublicKeyFile(String serverRSAPublicKeyFile) throws SQLException;
+
+	public abstract boolean getAllowPublicKeyRetrieval();
+
+	public abstract void setAllowPublicKeyRetrieval(boolean allowPublicKeyRetrieval) throws SQLException;
+
 }
