@@ -1,6 +1,5 @@
 /*
- Copyright (c) 2002, 2013, Oracle and/or its affiliates. All rights reserved.
- 
+  Copyright (c) 2002, 2014, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -20,9 +19,8 @@
   program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
   Floor, Boston, MA 02110-1301  USA
 
-
-
  */
+
 package com.mysql.jdbc.jdbc2.optional;
 
 import java.lang.reflect.Constructor;
@@ -2862,4 +2860,36 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	public String getConnectionAttributes() throws SQLException {
 		return this.mc.getConnectionAttributes();
 	}
+
+	public void setDetectCustomCollations(boolean detectCustomCollations) {
+		this.mc.setDetectCustomCollations(detectCustomCollations);
+	}
+
+	public boolean getDetectCustomCollations() {
+		return this.mc.getDetectCustomCollations();
+	}
+	
+	public int getSessionMaxRows() {
+		return this.mc.getSessionMaxRows();
+	}
+
+	public void setSessionMaxRows(int max) throws SQLException {
+		this.mc.setSessionMaxRows(max);
+	}
+
+	public String getServerRSAPublicKeyFile() {
+		return this.mc.getServerRSAPublicKeyFile();
+	}
+
+	public void setServerRSAPublicKeyFile(String serverRSAPublicKeyFile) throws SQLException {
+		this.mc.setServerRSAPublicKeyFile(serverRSAPublicKeyFile);
+	}
+
+	public boolean getAllowPublicKeyRetrieval() {
+		return this.mc.getAllowPublicKeyRetrieval();
+	}
+
+	public void setAllowPublicKeyRetrieval(boolean allowPublicKeyRetrieval) throws SQLException {
+		this.mc.setAllowPublicKeyRetrieval(allowPublicKeyRetrieval);
+	}
 }
\ No newline at end of file
