@@ -1,6 +1,5 @@
 /*
- Copyright (c) 2002, 2013, Oracle and/or its affiliates. All rights reserved.
- 
+  Copyright (c) 2002, 2014, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -20,9 +19,8 @@
   program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
   Floor, Boston, MA 02110-1301  USA
 
-
-
  */
+
 package testsuite;
 
 import java.io.BufferedOutputStream;
@@ -781,10 +779,16 @@ public abstract class BaseTestCase extends TestCase {
 			}
 		}
 	}
-	
+
+	protected void assertByteArrayEquals(String message, byte[] expected, byte[] actual) {
+		assertEquals(message + " - array lenght", expected.length, actual.length);
+		for (int i = 0, s = expected.length; i < s; i++) {
+			assertEquals(message + " - element at " + i, expected[i], actual[i]);
+		}
+	}
+
 	/*
-	 * Set default values for primitives.
-	 * (prevents NPE in Java 1.4 when calling via reflection)
+	 * Set default values for primitives. (prevents NPE in Java 1.4 when calling via reflection)
 	 */
 	protected void fillPrimitiveDefaults(Class<?> types[], Object vals[], int count) {
 		for (int i = 0; i < count; ++i) {
