@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2002, 2013, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2014, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -18,16 +18,22 @@
   You should have received a copy of the GNU General Public License along with this
   program; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth
   Floor, Boston, MA 02110-1301  USA
+
  */
+
 package testsuite.regression;
 
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
 import java.io.IOException;
+import java.sql.CallableStatement;
 import java.sql.Connection;
+import java.sql.DatabaseMetaData;
 import java.sql.SQLException;
+import java.sql.Statement;
 import java.util.Properties;
+import java.util.concurrent.Callable;
 
 import testsuite.BaseTestCase;
 
@@ -300,23 +306,49 @@ public class SyntaxRegressionTest extends BaseTestCase {
 	 * @throws SQLException
 	 */
 	public void testExchangePartition() throws Exception {
-
 		if (versionMeetsMinimum(5, 6, 6)) {
-			createTable("testExchangePartition1",
-				"(id int(11) NOT NULL AUTO_INCREMENT," +
-				" year year(2) DEFAULT NULL," +
-				" modified timestamp NOT NULL DEFAULT '0000-00-00 00:00:00'," +
-				" PRIMARY KEY (id))" +
-				" ENGINE=InnoDB ROW_FORMAT=COMPACT" +
-				" PARTITION BY HASH (id)" +
-				" PARTITIONS 2");
+			createTable("testExchangePartition1", "(id int(11) NOT NULL AUTO_INCREMENT, year year(2) DEFAULT NULL,"
+					+ " modified timestamp NOT NULL, PRIMARY KEY (id))"
+					+ " ENGINE=InnoDB ROW_FORMAT=COMPACT PARTITION BY HASH (id) PARTITIONS 2");
 			createTable("testExchangePartition2", "LIKE testExchangePartition1");
-			this.stmt.executeUpdate("ALTER TABLE testExchangePartition2 REMOVE PARTITIONING");
-			this.stmt.executeUpdate("ALTER IGNORE TABLE testExchangePartition1 EXCHANGE PARTITION p1 WITH TABLE testExchangePartition2");
 
-			this.pstmt = this.conn.prepareStatement("ALTER IGNORE TABLE testExchangePartition1 EXCHANGE PARTITION p1 WITH TABLE testExchangePartition2");
-			assertTrue(this.pstmt instanceof com.mysql.jdbc.PreparedStatement);
-			
+			this.stmt.executeUpdate("ALTER TABLE testExchangePartition2 REMOVE PARTITIONING");
+			if (versionMeetsMinimum(5, 7, 4)) {
+				this.stmt.executeUpdate("ALTER TABLE testExchangePartition1 "
+						+ "EXCHANGE PARTITION p1 WITH TABLE testExchangePartition2");
+			} else {
+				this.stmt.executeUpdate("ALTER IGNORE TABLE testExchangePartition1 "
+						+ "EXCHANGE PARTITION p1 WITH TABLE testExchangePartition2");
+			}
+
+			if (versionMeetsMinimum(5, 7, 4)) {
+				this.pstmt = this.conn.prepareStatement("ALTER TABLE testExchangePartition1 "
+						+ "EXCHANGE PARTITION p1 WITH TABLE testExchangePartition2");
+			} else {
+				this.pstmt = this.conn.prepareStatement("ALTER IGNORE TABLE testExchangePartition1 "
+						+ "EXCHANGE PARTITION p1 WITH TABLE testExchangePartition2");
+			}
+			assertEquals(com.mysql.jdbc.PreparedStatement.class, this.pstmt.getClass());
+			this.pstmt.executeUpdate();
+
+			Connection testConn = null;
+			try {
+				testConn = getConnectionWithProps("useServerPrepStmts=true,emulateUnsupportedPstmts=false");
+				if (versionMeetsMinimum(5, 7, 4)) {
+					this.pstmt = testConn.prepareStatement("ALTER TABLE testExchangePartition1 "
+							+ "EXCHANGE PARTITION p1 WITH TABLE testExchangePartition2");
+				} else {
+					this.pstmt = testConn.prepareStatement("ALTER IGNORE TABLE testExchangePartition1 "
+							+ "EXCHANGE PARTITION p1 WITH TABLE testExchangePartition2");
+
+				}
+				assertEquals(com.mysql.jdbc.ServerPreparedStatement.class, this.pstmt.getClass());
+				this.pstmt.executeUpdate();
+			} finally {
+				if (testConn != null) {
+					testConn.close();
+				}
+			}
 		}
 	}
 
@@ -693,4 +725,137 @@ public class SyntaxRegressionTest extends BaseTestCase {
 			this.rs.close();
 		}
 	}
+
+	/**
+	 * WL#6555 - Online rename index
+	 * 
+	 * ALTER TABLE syntax changed in 5.7.1
+	 * 
+	 * Alter table allows to rename indexes. ALTER TABLE ... RENAME INDEX x TO y
+	 * 
+	 * @throws SQLException
+	 */
+	public void testRenameIndex() throws Exception {
+
+		if (!versionMeetsMinimum(5, 7, 1)) {
+			return;
+		}
+
+		createTable("testRenameIndex", "(col1 INT, col2 INT, INDEX (col1)) ENGINE=InnoDB");
+		this.stmt.execute("CREATE INDEX testIdx ON testRenameIndex (col2)");
+
+		DatabaseMetaData dbmd = this.conn.getMetaData();
+
+		this.rs = dbmd.getIndexInfo(null, null, "testRenameIndex", false, true);
+		assertTrue("Expected 1 (of 2) indexes.", this.rs.next());
+		assertEquals("Wrong index name for table 'testRenameIndex'.", "col1", this.rs.getString(6));
+		assertTrue("Expected 2 (of 2) indexes.", this.rs.next());
+		assertEquals("Wrong index name for table 'testRenameIndex'.", "testIdx", this.rs.getString(6));
+		assertFalse("No more indexes expected for table 'testRenameIndex'.", this.rs.next());
+
+		this.stmt.execute("ALTER TABLE testRenameIndex RENAME INDEX col1 TO col1Index");
+		this.stmt.execute("ALTER TABLE testRenameIndex RENAME INDEX testIdx TO testIndex");
+
+		this.rs = dbmd.getIndexInfo(null, null, "testRenameIndex", false, true);
+		assertTrue("Expected 1 (of 2) indexes.", this.rs.next());
+		assertEquals("Wrong index name for table 'testRenameIndex'.", "col1Index", this.rs.getString(6));
+		assertTrue("Expected 2 (of 2) indexes.", this.rs.next());
+		assertEquals("Wrong index name for table 'testRenameIndex'.", "testIndex", this.rs.getString(6));
+		assertFalse("No more indexes expected for table 'testRenameIndex'.", this.rs.next());
+	}
+	
+	/**
+	 * WL#6406 - Stacked diagnostic areas
+	 * 
+	 * "STACKED" in "GET [CURRENT | STACKED] DIAGNOSTICS" syntax was added in 5.7.0. Final behavior was implemented in
+	 * version 5.7.2, by WL#5928 - Most statements should clear the diagnostic area.
+	 * 
+	 * @throws SQLException
+	 */
+	public void testGetStackedDiagnostics() throws Exception {
+
+		if (!versionMeetsMinimum(5, 7, 2)) {
+			return;
+		}
+
+		// test calling GET STACKED DIAGNOSTICS outside an handler
+		final Statement locallyScopedStmt = this.stmt;
+		assertThrows(SQLException.class, "GET STACKED DIAGNOSTICS when handler not active", new Callable<Void>() {
+			public Void call() throws Exception {
+				locallyScopedStmt.executeQuery("GET STACKED DIAGNOSTICS @num = NUMBER");
+				return null;
+			}
+		});
+
+		// test calling GET STACKED DIAGNOSTICS inside an handler
+		// (stored procedure is based on documentation example)
+		createTable("testGetStackedDiagnosticsTbl", "(c VARCHAR(8) NOT NULL)");
+		createProcedure("testGetStackedDiagnosticsSP", "() BEGIN DECLARE EXIT HANDLER FOR SQLEXCEPTION BEGIN "
+				+ "GET CURRENT DIAGNOSTICS CONDITION 1 @errno = MYSQL_ERRNO, @msg = MESSAGE_TEXT; "
+				+ "SELECT 'current DA before insert in handler' AS op, @errno AS errno, @msg AS msg; " // 1st result
+				+ "GET STACKED DIAGNOSTICS CONDITION 1 @errno = MYSQL_ERRNO, @msg = MESSAGE_TEXT; "
+				+ "SELECT 'stacked DA before insert in handler' AS op, @errno AS errno, @msg AS msg; " // 2nd result
+				+ "INSERT INTO testGetStackedDiagnosticsTbl (c) VALUES('gnitset'); "
+				+ "GET CURRENT DIAGNOSTICS @num = NUMBER; "
+				+ "IF @num = 0 THEN SELECT 'INSERT succeeded, current DA is empty' AS op; " // 3rd result
+				+ "ELSE GET CURRENT DIAGNOSTICS CONDITION 1 @errno = MYSQL_ERRNO, @msg = MESSAGE_TEXT; "
+				+ "SELECT 'current DA after insert in handler' AS op, @errno AS errno, @msg AS msg; END IF; "
+				+ "GET STACKED DIAGNOSTICS CONDITION 1 @errno = MYSQL_ERRNO, @msg = MESSAGE_TEXT; "
+				+ "SELECT 'stacked DA after insert in handler' AS op, @errno AS errno, @msg AS msg; END; " // 4th result
+				+ "INSERT INTO testGetStackedDiagnosticsTbl (c) VALUES ('testing');"
+				+ "INSERT INTO testGetStackedDiagnosticsTbl (c) VALUES (NULL); END");
+
+		CallableStatement cStmt = conn.prepareCall("CALL testGetStackedDiagnosticsSP()");
+		assertTrue(cStmt.execute());
+
+		// test 1st ResultSet
+		this.rs = cStmt.getResultSet();
+		assertTrue(this.rs.next());
+		assertEquals("current DA before insert in handler", this.rs.getString(1));
+		assertEquals(1048, this.rs.getInt(2));
+		assertEquals("Column 'c' cannot be null", this.rs.getString(3));
+		assertFalse(this.rs.next());
+		this.rs.close();
+
+		// test 2nd ResultSet
+		assertTrue(cStmt.getMoreResults());
+		this.rs = cStmt.getResultSet();
+		assertTrue(this.rs.next());
+		assertEquals("stacked DA before insert in handler", this.rs.getString(1));
+		assertEquals(1048, this.rs.getInt(2));
+		assertEquals("Column 'c' cannot be null", this.rs.getString(3));
+		assertFalse(this.rs.next());
+		this.rs.close();
+
+		// test 3rd ResultSet
+		assertTrue(cStmt.getMoreResults());
+		this.rs = cStmt.getResultSet();
+		assertTrue(this.rs.next());
+		assertEquals("INSERT succeeded, current DA is empty", this.rs.getString(1));
+		assertFalse(this.rs.next());
+		this.rs.close();
+
+		// test 4th ResultSet
+		assertTrue(cStmt.getMoreResults());
+		this.rs = cStmt.getResultSet();
+		assertTrue(this.rs.next());
+		assertEquals("stacked DA after insert in handler", this.rs.getString(1));
+		assertEquals(1048, this.rs.getInt(2));
+		assertEquals("Column 'c' cannot be null", this.rs.getString(3));
+		assertFalse(this.rs.next());
+		this.rs.close();
+
+		// no more ResultSets
+		assertFalse(cStmt.getMoreResults());
+		cStmt.close();
+
+		// test table contents
+		this.rs = this.stmt.executeQuery("SELECT * FROM testGetStackedDiagnosticsTbl");
+		assertTrue(this.rs.next());
+		assertEquals("testing", this.rs.getString(1));
+		assertTrue(this.rs.next());
+		assertEquals("gnitset", this.rs.getString(1));
+		assertFalse(this.rs.next());
+		this.rs.close();
+	}
 }
